Crate seripack_macros
seripack_
macros
0.1.0
All Items
Crate Items
Attribute Macros
Crate
seripack_
macros
Attribute Macros

route
When a router receives a packet it will search for the registered functions with this attribute and its matching Id and call it
route2
Same as ‘route’ macro but with different syntax